#[repr(C)]pub struct RCopyView {
pub data: *mut c_void,
pub vtable: *const RCopyVTable,
}Expand description
Runtime view for objects implementing RCopy.
Generated from source location line 454, column 11.
Generated from source file miniextendr-api/src/adapter_traits.rs.
Combines a data pointer with a vtable pointer for method dispatch.
Use try_from_sexp to create a view from an R external pointer.
Fields
data: *mut c_voidPointer to the concrete object data.
vtable: *const RCopyVTablePointer to the vtable for this trait.
Implementations
Sourceimpl RCopyView
impl RCopyView
Sourcepub unsafe fn try_from_sexp(sexp: SEXP) -> Option<Self>
pub unsafe fn try_from_sexp(sexp: SEXP) -> Option<Self>
Try to create a view from an R SEXP.
Returns Some(Self) if the object implements this trait,
None otherwise.
Safety
sexpmust be a valid R external pointer (EXTPTRSXP)- Must be called on R’s main thread