RDebugView

Struct RDebugView 

#[repr(C)]
pub struct RDebugView { pub data: *mut c_void, pub vtable: *const RDebugVTable, }
Runtime view for objects implementing RDebug. Generated from source location line 55, column 11. Generated from source file miniextendr-api/src/adapter_traits.rs.

Combines a data pointer with a vtable pointer for method dispatch. Use try_from_sexp to create a view from an R external pointer.

Fields

data: *mut c_void

Pointer to the concrete object data.

vtable: *const RDebugVTable

Pointer to the vtable for this trait.

Implementations

Source

impl RDebugView

pub unsafe fn try_from_sexp(sexp: SEXP) -> Option<Self>

Try to create a view from an R SEXP.

Returns Some(Self) if the object implements this trait, None otherwise.

Safety
  • sexp must be a valid R external pointer (EXTPTRSXP)
  • Must be called on R’s main thread
pub unsafe fn from_sexp(sexp: SEXP) -> Self

Try to create a view, panicking with error message on failure.

Safety

Same as try_from_sexp.

pub fn debug_str(&self) -> String

Call debug_str through the vtable.

pub fn debug_str_pretty(&self) -> String

Call debug_str_pretty through the vtable.