RAllocator

Struct RAllocator 

pub struct RAllocator;
R-backed global allocator.

All allocations are backed by R RAWSXP objects and protected from garbage collection. The allocator stores metadata before the returned pointer to enable proper deallocation.

Note: This should NOT be used as #[global_allocator] in R package library crates, as it would be invoked during compilation/build time when R isn’t available. Instead, use it explicitly in standalone binaries that embed R, or use arena-style allocation APIs.

Thread Safety

This allocator is safe to use from any thread. R API calls are automatically routed to the main thread via with_r_thread_or_inline.