pub unsafe fn install_lgl<T: AltLogical>(cls: R_altrep_class_t)Expand description
Install logical-specific methods.
Safety
Must be called during R initialization with a valid ALTREP class handle.
pub unsafe fn install_lgl<T: AltLogical>(cls: R_altrep_class_t)Install logical-specific methods.
Must be called during R initialization with a valid ALTREP class handle.