pub unsafe fn install_list<T: AltList>(cls: R_altrep_class_t)Expand description
Install list-specific methods.
Safety
Must be called during R initialization with a valid ALTREP class handle. Note: Elt is always installed for ALTLIST (required).
pub unsafe fn install_list<T: AltList>(cls: R_altrep_class_t)Install list-specific methods.
Must be called during R initialization with a valid ALTREP class handle. Note: Elt is always installed for ALTLIST (required).