pub unsafe fn install_raw<T: AltRaw>(cls: R_altrep_class_t)Expand description
Install raw-specific methods.
Safety
Must be called during R initialization with a valid ALTREP class handle.
pub unsafe fn install_raw<T: AltRaw>(cls: R_altrep_class_t)Install raw-specific methods.
Must be called during R initialization with a valid ALTREP class handle.