pub unsafe fn install_real<T: AltReal>(cls: R_altrep_class_t)Expand description
Install real-specific methods.
Safety
Must be called during R initialization with a valid ALTREP class handle.
pub unsafe fn install_real<T: AltReal>(cls: R_altrep_class_t)Install real-specific methods.
Must be called during R initialization with a valid ALTREP class handle.