Enum Logical
Source pub enum Logical {
False,
True,
Na,
}
Logical value: TRUE, FALSE, or NA.
Convert to R’s integer representation.
Convert from R’s integer representation.
Convert from Rust bool (no NA representation).
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read moreSourceConvert from Logical (semantic type) to RLogical (FFI type).
Converts to this type from the input type.
SourceConvert Logical to R’s integer representation.
Converts to this type from the input type.
SourceConvert from RLogical (FFI type) to Logical (semantic type).
Converts to this type from the input type.
SourceConvert from Rust bool to Logical (no NA representation).
Converts to this type from the input type.
SourceConvert from R’s integer representation to Logical.
Converts to this type from the input type.
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
Create a deep copy of this value.
Create a bitwise copy of this value.
Read more
Check if this type implements Copy.
Read more
Get a compact debug string representation.
Get a pretty-printed debug string with indentation.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.