pub struct IterIntCoerceData<I, T>{
state: IterState<I, T>,
}Expand description
Iterator-backed integer vector data adaptor with coercion from any integer-like type.
Wraps an iterator producing values that coerce to i32 (e.g., u16, i8, etc.)
and implements the data-level traits (AltrepLen + AltIntegerData).
To expose it to R, wrap it in a #[derive(AltrepInteger)] +
#[altrep(manual)] struct (see the module docs).
Example
ⓘ
use miniextendr_api::altrep_data::IterIntCoerceData;
// Create from an iterator of u16 values
let iter = (0..10u16).map(|x| x * 100);
let data = IterIntCoerceData::from_iter(iter, 10);
// Values are coerced from u16 to i32 when accessedFields
state: IterState<I, T>Implementations
Sourceimpl<I, T> IterIntCoerceData<I, T>
impl<I, T> IterIntCoerceData<I, T>
Sourceimpl<I, T> IterIntCoerceData<I, T>
impl<I, T> IterIntCoerceData<I, T>
Sourcepub fn from_exact_iter(iter: I) -> Self
pub fn from_exact_iter(iter: I) -> Self
Create from an ExactSizeIterator (length auto-detected).