IterRealCoerceData

Struct IterRealCoerceData 

pub struct IterRealCoerceData<I, T>
where I: Iterator<Item = T>, T: Coerce<f64> + Copy,
{ state: IterState<I, T>, }
Iterator-backed real vector data adaptor with coercion from any float-like type.

Wraps an iterator producing values that coerce to f64 (e.g., f32, integer types).

Example

use miniextendr_api::altrep_data::IterRealCoerceData;

// Create from an iterator of f32 values
let iter = (0..5).map(|x| x as f32 * 1.5);
let data = IterRealCoerceData::from_iter(iter, 5);
// Values are coerced from f32 to f64 when accessed

Fields

state: IterState<I, T>

Implementations

Source

impl<I, T> IterRealCoerceData<I, T>
where I: Iterator<Item = T>, T: Coerce<f64> + Copy,

pub fn from_iter(iter: I, len: usize) -> Self

Create from an iterator with explicit length.

Source

impl<I, T> IterRealCoerceData<I, T>
where I: ExactSizeIterator<Item = T>, T: Coerce<f64> + Copy,

pub fn from_exact_iter(iter: I) -> Self

Create from an ExactSizeIterator (length auto-detected).