r_generic_to_method

Function r_generic_to_method 

pub const fn r_generic_to_method(generic: &str) -> Option<&'static str>
Maps an R generic name to the corresponding trait method name.

This is used by the proc-macro to validate #[miniextendr(as = "...")] attributes.

Returns

The Rust method name that corresponds to the R generic, or None if the generic is not supported.