pub trait AsDate {
// Required method
fn as_date(&self) -> Result<SEXP, AsCoerceError>;
}Expand description
Trait for types that can be coerced to Date via as.Date().
The result should be an R Date object (numeric with “Date” class).
Required Methods
Sourcefn as_date(&self) -> Result<SEXP, AsCoerceError>
fn as_date(&self) -> Result<SEXP, AsCoerceError>
Convert to an R Date.