AsMatrix

Trait AsMatrix 

pub trait AsMatrix {
    // Required method
    fn as_matrix(&self) -> Result<SEXP, AsCoerceError>;
}
Trait for types that can be coerced to matrix via as.matrix().

The result should be an R matrix with appropriate dimensions.

Required Methods

fn as_matrix(&self) -> Result<SEXP, AsCoerceError>

Convert to an R matrix.

Implementors