AsRaw

Trait AsRaw 

pub trait AsRaw {
    // Required method
    fn as_raw(&self) -> Result<SEXP, AsCoerceError>;
}
Trait for types that can be coerced to raw via as.raw().

The result should be an R raw vector (RAWSXP).

Required Methods

fn as_raw(&self) -> Result<SEXP, AsCoerceError>

Convert to an R raw vector.

Implementors