AsVector

Trait AsVector 

pub trait AsVector {
    // Required method
    fn as_vector(&self) -> Result<SEXP, AsCoerceError>;
}
Trait for types that can be coerced to a generic vector via as.vector().

This is the most general vector coercion, typically stripping attributes.

Required Methods

fn as_vector(&self) -> Result<SEXP, AsCoerceError>

Convert to an R vector.

Implementors