pub struct AsDisplay<T>(pub T);Expand description
Wrap a T: Display and convert it to an R character scalar.
Any type implementing std::fmt::Display can be returned to R as a string
without implementing miniextendr traits.
Example
ⓘ
use std::net::IpAddr;
#[miniextendr]
fn format_ip(ip: &str) -> AsDisplay<IpAddr> {
AsDisplay(ip.parse().unwrap())
}
// R gets: "192.168.1.1"Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Display> IntoR for AsDisplay<T>
impl<T: Display> IntoR for AsDisplay<T>
Sourcetype Error = Infallible
type Error = Infallible
The error type for fallible conversions. Read more
Sourcefn try_into_sexp(self) -> Result<SEXP, Self::Error>
fn try_into_sexp(self) -> Result<SEXP, Self::Error>
Try to convert this value to an R SEXP. Read more
Sourceunsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
unsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
Try to convert to SEXP without thread safety checks. Read more
impl<T: Copy> Copy for AsDisplay<T>