pub struct CollectNAInt<I>(pub I);Expand description
Write an ExactSizeIterator of Option<i32> directly into an R integer vector with NA.
Like Collect, this is an iterator adapter and is exempt from the As*
naming convention (see #871).
Tuple Fields
0: ITrait Implementations
Sourceimpl<I> IntoR for CollectNAInt<I>
impl<I> IntoR for CollectNAInt<I>
Sourcetype Error = Infallible
type Error = Infallible
The error type for fallible conversions. Read more
Sourcefn try_into_sexp(self) -> Result<SEXP, Self::Error>
fn try_into_sexp(self) -> Result<SEXP, Self::Error>
Try to convert this value to an R SEXP. Read more
Sourceunsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
unsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
Try to convert to SEXP without thread safety checks. Read more
Sourceunsafe fn into_sexp_unchecked(self) -> SEXP
unsafe fn into_sexp_unchecked(self) -> SEXP
Convert to SEXP without thread safety checks, panicking on error. Read more