CollectStrings

Struct CollectStrings 

pub struct CollectStrings<I>(pub I);
Write an ExactSizeIterator of String directly into an R character vector.

Strings require per-element CHARSXP allocation (no bulk copy_from_slice), so this is a separate type from Collect. Like Collect, it is an iterator adapter and is exempt from the As* naming convention (see #871).

Example

#[miniextendr]
fn upper(words: Vec<String>) -> CollectStrings<impl ExactSizeIterator<Item = String>> {
    CollectStrings(words.into_iter().map(|w| w.to_uppercase()))
}

Tuple Fields

0: I