DataFrame

Struct DataFrame 

pub struct DataFrame<T: IntoList> {
    rows: Vec<T>,
}
Convert row-oriented data into a column-oriented R data.frame.

This type collects a sequence of row elements (structs implementing IntoList) and transposes them into column vectors suitable for creating an R data.frame.

Example

use miniextendr_api::{miniextendr, convert::DataFrame};

#[derive(IntoList)]
struct Person {
    name: String,
    age: i32,
    height: f64,
}

#[miniextendr]
fn make_people() -> DataFrame<Person> {
    DataFrame::from_rows(vec![
        Person { name: "Alice".into(), age: 30, height: 165.0 },
        Person { name: "Bob".into(), age: 25, height: 180.0 },
        Person { name: "Carol".into(), age: 35, height: 170.0 },
    ])
}
// In R: make_people() returns a data.frame with 3 rows and columns: name, age, height

Row-oriented to Column-oriented

R data frames are column-oriented (each column is a vector), but data is often produced row-by-row in Rust. DataFrame handles the transposition:

Input (row-oriented):           Output (column-oriented):
Row 1: {name: "A", age: 30}     name column:  ["A", "B", "C"]
Row 2: {name: "B", age: 25}  →  age column:   [30, 25, 35]
Row 3: {name: "C", age: 35}

Fields

rows: Vec<T>

Implementations

Source

impl<T: IntoList> DataFrame<T>

pub fn from_rows(rows: Vec<T>) -> Self

Create a new DataFrame from a vector of row elements.

pub fn new() -> Self

Create an empty DataFrame.

pub fn push(&mut self, row: T)

Add a row to the data frame.

pub fn len(&self) -> usize

Get the number of rows.

pub fn is_empty(&self) -> bool

Check if empty.