r_stop

Function r_stop 

pub(crate) fn r_stop(msg: &str) -> !
Raise an R error via Rf_error (longjmp). Crate-internal only.

Survives at two guard sites where there is no SEXP slot to return through:

User code should use panic!() (caught by the framework and converted to a rust_error R condition) or the structured condition macros error!() / warning!() / message!() / condition!().

Panics

Panics if the message contains null bytes.