SendableAnyPtr

Type Alias SendableAnyPtr 

type SendableAnyPtr = Sendable<NonNull<Box<dyn Any>>>;
A wrapper around a raw pointer that implements Send.

Safety

This is safe to send between threads because it’s just a memory address. The data is owned and transferred to the main thread before being accessed.

Aliased Type

#[repr(transparent)]
struct SendableAnyPtr(pub NonNull<Box<dyn Any>>);

Tuple Fields

0: NonNull<Box<dyn Any>>

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 8 bytes