macro_rules! impl_te {
($ty:ty, $name:literal) => { ... };
}Expand description
Implement TypedExternal for a concrete type. For standard library types, we use the simple name for both display and ID.
macro_rules! impl_te {
($ty:ty, $name:literal) => { ... };
}Implement TypedExternal for a concrete type. For standard library types, we use the simple name for both display and ID.