R_ReleaseObject_unchecked

Function R_ReleaseObject_unchecked 

pub unsafe extern "C-unwind" fn R_ReleaseObject_unchecked(
    object: SEXP,
)
Remove a SEXP from the global precious list, allowing GC.

Cost: O(n) — linear scan of the entire precious list to find and unlink the cons cell. With R_HASH_PRECIOUS env var, O(bucket_size) average via a 1069-bucket hash table, but this is off by default. Unchecked FFI binding for R_ReleaseObject. Generated from source location line 2125, column 12. Generated from source file miniextendr-api/src/ffi.rs.