DL_FUNC

Type Alias DL_FUNC 

pub type DL_FUNC = Option<unsafe extern "C-unwind" fn() -> *mut c_void>;
Generic dynamic library function pointer.

R defines this as void *(*)(void) - a function taking no arguments and returning void*. This is used for method registration and external pointer functions. The actual function signatures vary; callers cast to the appropriate concrete function type before calling.

We use fn() -> *mut c_void to match R’s signature. The function pointer is stored generically and cast to the appropriate type when called by R.

Aliased Type

pub enum DL_FUNC {
    None,
    Some(unsafe extern "C-unwind" fn() -> *mut c_void),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C-unwind" fn() -> *mut c_void)

Some value of type T.