macro_rules! impl_option_coerce_into_r {
($from:ty => $to:ty) => { ... };
}Expand description
Macro for Option<T> where T coerces to a type with existing Option impl.
macro_rules! impl_option_coerce_into_r {
($from:ty => $to:ty) => { ... };
}Macro for Option<T> where T coerces to a type with existing Option impl.