__impl_altvec_string_dataptr

Macro __impl_altvec_string_dataptr 

#[doc(hidden)]
macro_rules! __impl_altvec_string_dataptr { ($ty:ty) => { ... }; }
Internal macro: impl AltVec with dataptr support for string ALTREP.

String vectors (STRSXP) store CHARSXP pointers, not contiguous data. This macro materializes remaining uncached elements into the data2 STRSXP cache (which may already have some elements from prior Elt calls). Returns the cached STRSXP’s data pointer.