macro_rules! impl_altlist_from_data {
($ty:ty) => { ... };
($ty:ty, $guard:ident) => { ... };
}Expand description
Generate ALTREP trait implementations for a type that implements AltListData.
macro_rules! impl_altlist_from_data {
($ty:ty) => { ... };
($ty:ty, $guard:ident) => { ... };
}Generate ALTREP trait implementations for a type that implements AltListData.