macro_rules! impl_vec_option_try_from_sexp_list {
($t:ty) => { ... };
}Expand description
Implement TryFromSexp for Vec<Option<T>> from R list (VECSXP).
NULL elements become None, others are converted via T::try_from_sexp.
macro_rules! impl_vec_option_try_from_sexp_list {
($t:ty) => { ... };
}Implement TryFromSexp for Vec<Option<T>> from R list (VECSXP).
NULL elements become None, others are converted via T::try_from_sexp.