pub trait WidensToF64: Into<f64> + Copy { }Expand description
Marker trait for types that can widen to f64 without loss.
Manually implemented for specific types to avoid conflicts with identity/ special-case conversions. Used by blanket Coerce implementations.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".