fn match_choice<T: MatchArg>(input: &str) -> Result<T, MatchArgError>Expand description
Match a string against the choices of a MatchArg type (exact or partial).
fn match_choice<T: MatchArg>(input: &str) -> Result<T, MatchArgError>Match a string against the choices of a MatchArg type (exact or partial).