pub struct NamedVector<M>(pub M);Expand description
Wrapper that converts a map to/from a named atomic R vector instead of a named list.
The inner map must have String keys and values that implement AtomicElement.
Supported value types
| Rust type | R SEXPTYPE |
|---|---|
i32 | INTSXP |
f64 | REALSXP |
u8 | RAWSXP |
bool | LGLSXP |
String | STRSXP |
Option<i32> | INTSXP (NA = NA_INTEGER) |
Option<f64> | REALSXP (NA = NA_REAL) |
Option<bool> | LGLSXP (NA = NA_LOGICAL) |
Option<String> | STRSXP (NA = NA_character_) |
Tuple Fields
0: MImplementations
Sourceimpl<M> NamedVector<M>
impl<M> NamedVector<M>
Sourcepub fn into_inner(self) -> M
pub fn into_inner(self) -> M
Unwrap, returning the inner map.