insert

Function insert 

pub unsafe fn insert(x: SEXP) -> SEXP
Insert a SEXP into the preservation list, protecting it from GC.

Returns a “cell” (a cons cell) that can later be passed to release to stop protecting the object.

If x is R_NilValue, returns R_NilValue without protection (since NIL is never collected).

Safety

Must be called from the R main thread. The returned cell must eventually be passed to release to prevent leaking memory in the preserve list.