RCoerceVector

Trait RCoerceVector 

pub trait RCoerceVector {
    // Required method
    fn as_vector(&self) -> Result<SEXP, RCoerceError>;
}
Trait for types that can be coerced to a generic vector via as.vector().

This is the most general vector coercion, typically stripping attributes.

Required Methods

fn as_vector(&self) -> Result<SEXP, RCoerceError>

Convert to an R vector.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors