pub type FastHashMap = HashMap<usize, Entry, RandomState>;Expand description
HashMap with ahash for faster hashing (not DOS-resistant).
Uses ahash instead of SipHash for improved throughput. Not DOS-resistant, suitable for local, non-hostile environments.
Aliased Type
pub struct FastHashMap { /* private fields */ }Trait Implementations
Sourceimpl MapStorage for FastHashMap
impl MapStorage for FastHashMap
Sourcefn decrement_and_maybe_remove(&mut self, key: &usize) -> Option<(bool, usize)>
fn decrement_and_maybe_remove(&mut self, key: &usize) -> Option<(bool, usize)>
Entry-based decrement for single-lookup performance.
Sourcefn insert(&mut self, key: usize, entry: Entry) -> Option<Entry>
fn insert(&mut self, key: usize, entry: Entry) -> Option<Entry>
Insert an entry, returning the old value if present.
Sourcefn contains_key(&self, key: &usize) -> bool
fn contains_key(&self, key: &usize) -> bool
Check if a key exists.
Sourcefn for_each_entry<F: FnMut(&Entry)>(&self, f: F)
fn for_each_entry<F: FnMut(&Entry)>(&self, f: F)
Iterate over all entries.
Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 64 bytes