macro_rules! try_from_vec {
($t:ty, $variant:ident, $ty:expr) => { ... };
}Expand description
TryFrom<RValue> for the whole vector of a single variant (NA preserved).
macro_rules! try_from_vec {
($t:ty, $variant:ident, $ty:expr) => { ... };
}TryFrom<RValue> for the whole vector of a single variant (NA preserved).