scalar_string

Function scalar_string 

fn scalar_string(s: &str) -> SEXP
Create a scalar R character string from a Rust &str.

The returned SEXP is unprotected — caller must protect if further allocations will occur before use.