AltrepPkgName

Struct AltrepPkgName 

#[doc(hidden)]
pub struct AltrepPkgName;
Returns the current ALTREP package name as a C string pointer. This is set by the C entrypoint before ALTREP registration.

Implementations

Source

impl AltrepPkgName

pub fn as_ptr() -> *const c_char

Get the package name pointer.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 0 bytes