fn read_runtime_slices() -> (Vec<CallDefRow>, Vec<AltrepRegRow>, Vec<TraitDispatchRow>)Expand description
Read the live linkme distributed slices and return rows safe to pass to
format_wasm_registry.
fn read_runtime_slices() -> (Vec<CallDefRow>, Vec<AltrepRegRow>, Vec<TraitDispatchRow>)Read the live linkme distributed slices and return rows safe to pass to
format_wasm_registry.