Sendable

Struct Sendable 

#[doc(hidden)]
#[repr(transparent)]
pub struct Sendable<T>(pub T);
Wrapper to mark values as Send for main-thread routing.

Only safe if the value is not accessed on the worker thread and is used exclusively on the main thread.

Tuple Fields

0: T