RHashView

Struct RHashView 

#[repr(C)]
pub struct RHashView { pub data: *mut c_void, pub vtable: *const RHashVTable, }
Runtime view for objects implementing RHash. Generated from source location line 132, column 11. Generated from source file miniextendr-api/src/adapter_traits.rs.

Combines a data pointer with a vtable pointer for method dispatch. Use try_from_sexp to create a view from an R external pointer.

Fields

data: *mut c_void

Pointer to the concrete object data.

vtable: *const RHashVTable

Pointer to the vtable for this trait.

Implementations

Source

impl RHashView

pub unsafe fn try_from_sexp(sexp: SEXP) -> Option<Self>

Try to create a view from an R SEXP.

Returns Some(Self) if the object implements this trait, None otherwise.

Safety
  • sexp must be a valid R external pointer (EXTPTRSXP)
  • Must be called on R’s main thread
pub unsafe fn from_sexp(sexp: SEXP) -> Self

Try to create a view, panicking with error message on failure.

Safety

Same as try_from_sexp.

pub fn hash(&self) -> i64

Call hash through the vtable.