pub unsafe fn make_class_by_base(
class_name: *const i8,
pkg_name: *const i8,
base: RBase,
) -> R_altrep_class_tExpand description
Create an ALTREP class handle based on the runtime base type.
Validates the returned handle and panics if registration fails.
Safety
Must be called during R initialization (after set_altrep_dll_info).