macro_rules! impl_serialize {
($ty:ty) => { ... };
}Expand description
Implement AltrepSerialize for types that can be cloned and converted to/from R.
This serializes by converting to a native R vector, ensuring the data survives even if the Rust package isn’t loaded when unserializing.