pub struct IterRealCoerceData<I, T>{
state: IterState<I, T>,
}Expand description
Iterator-backed real vector data adaptor with coercion from any float-like type.
Wraps an iterator producing values that coerce to f64 (e.g., f32, integer types).
Example
ⓘ
use miniextendr_api::altrep_data::IterRealCoerceData;
// Create from an iterator of f32 values
let iter = (0..5).map(|x| x as f32 * 1.5);
let data = IterRealCoerceData::from_iter(iter, 5);
// Values are coerced from f32 to f64 when accessedFields
state: IterState<I, T>Implementations
Sourceimpl<I, T> IterRealCoerceData<I, T>
impl<I, T> IterRealCoerceData<I, T>
Sourceimpl<I, T> IterRealCoerceData<I, T>
impl<I, T> IterRealCoerceData<I, T>
Sourcepub fn from_exact_iter(iter: I) -> Self
pub fn from_exact_iter(iter: I) -> Self
Create from an ExactSizeIterator (length auto-detected).