pub struct StreamingRealData<F: Fn(usize, &mut [f64]) -> usize> {
len: usize,
reader: F,
cache: RefCell<BTreeMap<usize, Vec<f64>>>,
chunk_size: usize,
}Expand description
Streaming data adaptor for ALTREP real (f64) vectors.
Elements are loaded on-demand via a reader closure in fixed-size chunks.
Chunks are cached in a BTreeMap for repeated access.
Reader Contract
The reader F(start, buf) -> count fills buf with elements starting
at index start and returns the number of elements actually written.
Example
ⓘ
use miniextendr_api::altrep_data::StreamingRealData;
let data = StreamingRealData::new(1000, 64, |start, buf| {
let count = buf.len().min(1000 - start);
for (i, slot) in buf[..count].iter_mut().enumerate() {
*slot = (start + i) as f64 * 0.1;
}
count
});Fields
len: usizereader: Fcache: RefCell<BTreeMap<usize, Vec<f64>>>chunk_size: usizeImplementations
Sourceimpl<F: Fn(usize, &mut [f64]) -> usize> StreamingRealData<F>
impl<F: Fn(usize, &mut [f64]) -> usize> StreamingRealData<F>
Sourcepub fn new(len: usize, chunk_size: usize, reader: F) -> Self
pub fn new(len: usize, chunk_size: usize, reader: F) -> Self
Create a new streaming real data source.
len: total number of elementschunk_size: number of elements per cache chunkreader: closure that fills a buffer starting at a given index
Sourcefn ensure_chunk(&self, chunk_idx: usize)
fn ensure_chunk(&self, chunk_idx: usize)
Load a chunk into the cache if not already present.