pub trait AsMatrix {
// Required method
fn as_matrix(&self) -> Result<SEXP, AsCoerceError>;
}Expand description
Trait for types that can be coerced to matrix via as.matrix().
The result should be an R matrix with appropriate dimensions.
Required Methods
Sourcefn as_matrix(&self) -> Result<SEXP, AsCoerceError>
fn as_matrix(&self) -> Result<SEXP, AsCoerceError>
Convert to an R matrix.