miniextendr_panic_hook

Function miniextendr_panic_hook 

#[unsafe(no_mangle)]
pub extern "C-unwind" fn miniextendr_panic_hook()
This function registers a configurable print panic hook, for use in miniextendr-based R-packages. If the environment variable MINIEXTENDR_BACKTRACE is set to either true or 1, then it displays the entire Rust panic traceback (default hook), otherwise it omits the panic backtrace.