pub struct AsDataFrame<T: IntoDataFrame>(pub T);Expand description
Wrap a value and convert it to an R data.frame via IntoDataFrame when returned.
Use this at a call site to force a single return value into a data.frame without making
that the type’s default representation (for the always-a-data.frame default, use
#[derive(PreferDataFrame)] / #[miniextendr(dataframe)]). The inner T is typically a
Vec<Row> where Row derives DataFrameRow.
A failed conversion (DataFrameError) surfaces in R as
an error condition.
Example
ⓘ
#[derive(DataFrameRow)]
struct Point { x: f64, y: f64 }
#[miniextendr]
fn grid() -> AsDataFrame<Vec<Point>> {
AsDataFrame(vec![Point { x: 0.0, y: 0.0 }, Point { x: 1.0, y: 1.0 }])
}
// In R: grid() returns a data.frame with columns x, yTuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone + IntoDataFrame> Clone for AsDataFrame<T>
impl<T: Clone + IntoDataFrame> Clone for AsDataFrame<T>
Sourcefn clone(&self) -> AsDataFrame<T>
fn clone(&self) -> AsDataFrame<T>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug + IntoDataFrame> Debug for AsDataFrame<T>
impl<T: Debug + IntoDataFrame> Debug for AsDataFrame<T>
Sourceimpl<T: IntoDataFrame> From<T> for AsDataFrame<T>
impl<T: IntoDataFrame> From<T> for AsDataFrame<T>
Sourceimpl<T: IntoDataFrame> IntoR for AsDataFrame<T>
impl<T: IntoDataFrame> IntoR for AsDataFrame<T>
Sourcetype Error = DataFrameError
type Error = DataFrameError
The error type for fallible conversions. Read more
Sourcefn try_into_sexp(self) -> Result<SEXP, Self::Error>
fn try_into_sexp(self) -> Result<SEXP, Self::Error>
Try to convert this value to an R SEXP. Read more
Sourceunsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
unsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
Try to convert to SEXP without thread safety checks. Read more