pub struct Collect<I>(pub I);Expand description
Write an ExactSizeIterator of native R types directly into an R vector.
Skips the intermediate Vec allocation — the R vector is allocated once
and the iterator writes directly into it.
Requires ExactSizeIterator because R vectors must know their length
at allocation time.
Example
ⓘ
#[miniextendr]
fn sines(n: i32) -> Collect<impl ExactSizeIterator<Item = f64>> {
Collect((0..n).map(|i| (i as f64).sin()))
}Tuple Fields
0: ITrait Implementations
Sourceimpl<I, T> IntoR for Collect<I>where
I: ExactSizeIterator<Item = T>,
T: RNativeType,
impl<I, T> IntoR for Collect<I>where
I: ExactSizeIterator<Item = T>,
T: RNativeType,
Sourcetype Error = Infallible
type Error = Infallible
The error type for fallible conversions. Read more
Sourcefn try_into_sexp(self) -> Result<SEXP, Self::Error>
fn try_into_sexp(self) -> Result<SEXP, Self::Error>
Try to convert this value to an R SEXP. Read more
Sourceunsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
unsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
Try to convert to SEXP without thread safety checks. Read more
Sourceunsafe fn into_sexp_unchecked(self) -> SEXP
unsafe fn into_sexp_unchecked(self) -> SEXP
Convert to SEXP without thread safety checks, panicking on error. Read more