pub struct CollectStrings<I>(pub I);Expand description
Write an ExactSizeIterator of String directly into an R character vector.
Strings require per-element CHARSXP allocation (no bulk copy_from_slice),
so this is a separate type from Collect.
Example
ⓘ
#[miniextendr]
fn upper(words: Vec<String>) -> CollectStrings<impl ExactSizeIterator<Item = String>> {
CollectStrings(words.into_iter().map(|w| w.to_uppercase()))
}Tuple Fields
0: ITrait Implementations
Sourceimpl<I> IntoR for CollectStrings<I>where
I: ExactSizeIterator<Item = String>,
impl<I> IntoR for CollectStrings<I>where
I: ExactSizeIterator<Item = String>,
Sourcetype Error = Infallible
type Error = Infallible
The error type for fallible conversions. Read more
Sourcefn try_into_sexp(self) -> Result<SEXP, Self::Error>
fn try_into_sexp(self) -> Result<SEXP, Self::Error>
Try to convert this value to an R SEXP. Read more
Sourceunsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
unsafe fn try_into_sexp_unchecked(self) -> Result<SEXP, Self::Error>
Try to convert to SEXP without thread safety checks. Read more