ToDataFrame

Struct ToDataFrame 

pub struct ToDataFrame<T: IntoDataFrame>(pub T);
Wrap a value and convert it to an R data.frame via IntoDataFrame when returned from Rust.

Use this wrapper when you want to convert a single value to an R data.frame without making that the default behavior for the type.

Example

struct TimeSeries {
    timestamps: Vec<f64>,
    values: Vec<f64>,
}

impl IntoDataFrame for TimeSeries {
    fn into_data_frame(self) -> List {
        List::from_pairs(vec![
            ("timestamp", self.timestamps),
            ("value", self.values),
        ])
        .set_class_str(&["data.frame"])
        .set_row_names_int(self.timestamps.len())
    }
}

#[miniextendr]
fn make_time_series() -> ToDataFrame<TimeSeries> {
    ToDataFrame(TimeSeries {
        timestamps: vec![1.0, 2.0, 3.0],
        values: vec![10.0, 20.0, 30.0],
    })
}
// In R: make_time_series() returns a data.frame

Tuple Fields

0: T