SendableAnyPtr

Type Alias SendableAnyPtr 

type SendableAnyPtr = Sendable<NonNull<Box<dyn Any>>>;
A wrapper around a raw pointer that implements Send.

Safety

This is safe to send between threads because it’s just a memory address. The data is owned and transferred to the main thread before being accessed.

Aliased Type

struct SendableAnyPtr(/* private fields */);