pub unsafe fn R_ReleaseObject(object: SEXP)Expand description
Remove a SEXP from the global precious list, allowing GC.
Cost: O(n) — linear scan of the entire precious list to find and unlink
the cons cell. With R_HASH_PRECIOUS env var, O(bucket_size) average
via a 1069-bucket hash table, but this is off by default.
Checked wrapper for R_ReleaseObject. Calls R_ReleaseObject_unchecked and routes through with_r_thread.
Generated from source location line 2125, column 12.
Generated from source file miniextendr-api/src/ffi.rs.