Root

Struct Root 

pub struct Root<'a> {
    sexp: SEXP,
    _scope: PhantomData<&'a ProtectScope>,
}
A rooted SEXP tied to the lifetime of a ProtectScope.

This type has no Drop. The scope owns unprotection responsibility. This makes Root cheap to move and copy (it’s just a pointer + lifetime).

Lifetime

The 'a lifetime ties the root to its creating scope. The compiler ensures you cannot use the root after the scope has been dropped.

Fields

sexp: SEXP_scope: PhantomData<&'a ProtectScope>

Implementations

Source

impl<'a> Root<'a>

pub fn get(&self) -> SEXP

Get the underlying SEXP.

pub fn into_raw(self) -> SEXP

Consume the root and return the underlying SEXP.

The SEXP remains protected until the scope drops.