pub struct Root<'a> {
sexp: SEXP,
_scope: PhantomData<&'a ProtectScope>,
}Expand description
A rooted SEXP tied to the lifetime of a ProtectScope.
This type has no Drop. The scope owns unprotection responsibility.
This makes Root cheap to move and copy (it’s just a pointer + lifetime).
Lifetime
The 'a lifetime ties the root to its creating scope. The compiler ensures
you cannot use the root after the scope has been dropped.
Fields
sexp: SEXP_scope: PhantomData<&'a ProtectScope>Implementations