TlsRoot

Struct TlsRoot 

pub struct TlsRoot {
    sexp: SEXP,
}
A rooted SEXP from TLS protection.

This is similar to super::Root but without a compile-time lifetime tie to the scope. The protection is valid as long as the enclosing with_protect_scope block hasn’t exited.

Warning

Using a TlsRoot after its scope has exited is undefined behavior. The compile-time lifetime checking of super::Root is safer; use TLS convenience only when necessary.

Fields

sexp: SEXP

Implementations

Source

impl TlsRoot

pub fn get(&self) -> SEXP

Get the underlying SEXP.

pub fn into_raw(self) -> SEXP

Consume and return the underlying SEXP.