TryFromList

Trait TryFromList 

pub trait TryFromList: Sized {
    type Error;

    // Required method
    fn try_from_list(list: List) -> Result<Self, Self::Error>;
}
Fallible conversion from an R list into a Rust value.

Required Associated Types

type Error

Error returned when conversion fails.

Required Methods

fn try_from_list(list: List) -> Result<Self, Self::Error>

Attempt to convert an R list wrapper into Self.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<T> TryFromList for BTreeSet<T>
where T: TryFromSexp<Error = SexpError> + Ord,

Source

impl<T> TryFromList for Vec<T>
where T: TryFromSexp<Error = SexpError>,

Source

impl<T> TryFromList for HashSet<T>
where T: TryFromSexp<Error = SexpError> + Eq + Hash,

Source

impl<V> TryFromList for BTreeMap<String, V>
where V: TryFromSexp<Error = SexpError>,

Source

impl<V> TryFromList for HashMap<String, V>
where V: TryFromSexp<Error = SexpError>,

Implementors