impl_altcomplex_from_data

Macro impl_altcomplex_from_data 

macro_rules! impl_altcomplex_from_data {
    ($ty:ty) => { ... };
    ($ty:ty, dataptr) => { ... };
    ($ty:ty, serialize) => { ... };
    ($ty:ty, subset) => { ... };
    ($ty:ty, dataptr, serialize) => { ... };
    ($ty:ty, serialize, dataptr) => { ... };
    ($ty:ty, subset, serialize) => { ... };
    ($ty:ty, serialize, subset) => { ... };
}
Generate ALTREP trait implementations for a type that implements AltComplexData.

Optional features can be enabled by passing additional arguments:

  • dataptr: Enable Dataptr and Dataptr_or_null methods (requires AltrepDataptr<Rcomplex>)
  • serialize: Enable serialization support (requires AltrepSerialize)
  • subset: Enable optimized subsetting (requires AltrepExtractSubset)