macro_rules! impl_altcomplex_from_data {
($ty:ty) => { ... };
($ty:ty, dataptr) => { ... };
($ty:ty, serialize) => { ... };
($ty:ty, subset) => { ... };
($ty:ty, dataptr, serialize) => { ... };
($ty:ty, serialize, dataptr) => { ... };
($ty:ty, subset, serialize) => { ... };
($ty:ty, serialize, subset) => { ... };
}Expand description
Generate ALTREP trait implementations for a type that implements AltComplexData.
Optional features can be enabled by passing additional arguments:
dataptr: EnableDataptrandDataptr_or_nullmethods (requiresAltrepDataptr<Rcomplex>)serialize: Enable serialization support (requiresAltrepSerialize)subset: Enable optimized subsetting (requiresAltrepExtractSubset)