WidensToI32

Trait WidensToI32 

pub trait WidensToI32: Into<i32> + Copy { }
Marker trait for types that can widen to i32 without loss.

Manually implemented for specific types to avoid conflicts with identity/ special-case conversions. Used by blanket Coerce implementations.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl WidensToI32 for i8

Source

impl WidensToI32 for i16

Source

impl WidensToI32 for u8

Source

impl WidensToI32 for u16

Implementors