pub trait WidensToI32: Into<i32> + Copy { }Expand description
Marker trait for types that can widen to i32 without loss.
Manually implemented for specific types to avoid conflicts with identity/ special-case conversions. Used by blanket Coerce implementations.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.