NamedVector

Struct NamedVector 

pub struct NamedVector<M>(pub M);
Wrapper that converts a map to/from a named atomic R vector instead of a named list.

The inner map must have String keys and values that implement AtomicElement.

Supported value types

Rust typeR SEXPTYPE
i32INTSXP
f64REALSXP
u8RAWSXP
boolLGLSXP
StringSTRSXP
Option<i32>INTSXP (NA = NA_INTEGER)
Option<f64>REALSXP (NA = NA_REAL)
Option<bool>LGLSXP (NA = NA_LOGICAL)
Option<String>STRSXP (NA = NA_character_)

Tuple Fields

0: M

Implementations

Source

impl<M> NamedVector<M>

pub fn into_inner(self) -> M

Unwrap, returning the inner map.