pub unsafe fn release(cell: SEXP)Expand description
Release a previously protected SEXP from the preservation list.
The cell parameter should be a value returned from insert.
If cell is R_NilValue, this is a no-op.
Safety
Must be called from the R main thread. The cell must be a valid
cell returned from insert and must not have been released already.