pub type WorkerError = Box<dyn Error + Send + Sync>;Expand description
Boxed, thread-safe error type used by WorkerPump::run.
Alias for Box<dyn Error + Send + Sync>. Compatible with anyhow::Error
via ? and with standard library error types without requiring extra
dependencies.
Aliased Type
pub struct WorkerError(/* private fields */);Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 16 bytes