pub trait RCoerceDate {
// Required method
fn as_date(&self) -> Result<SEXP, RCoerceError>;
}Expand description
Trait for types that can be coerced to Date via as.Date().
The result should be an R Date object (numeric with “Date” class).
Required Methods
Sourcefn as_date(&self) -> Result<SEXP, RCoerceError>
fn as_date(&self) -> Result<SEXP, RCoerceError>
Convert to an R Date.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".