StrVecBuilder

Struct StrVecBuilder 

pub struct StrVecBuilder<'a> {
    vec: SEXP,
    _scope: &'a ProtectScope,
}
Builder for constructing string vectors with efficient protection management.

Example

unsafe fn build_strvec(strings: &[&str]) -> SEXP {
    let scope = ProtectScope::new();
    let builder = StrVecBuilder::new(&scope, strings.len() as isize);

    for (i, s) in strings.iter().enumerate() {
        builder.set_str(i as isize, s);
    }

    builder.into_sexp()
}

Fields

vec: SEXP_scope: &'a ProtectScope

Implementations

Source

impl<'a> StrVecBuilder<'a>

pub unsafe fn new(scope: &'a ProtectScope, len: usize) -> Self

Create a new string vector builder with the given length.

Safety

Must be called from the R main thread.

pub unsafe fn set_str(&self, idx: isize, s: &str)

Set an element from a Rust string.

Safety

Must be called from the R main thread.

pub unsafe fn set_na(&self, idx: isize)

Set an element to NA_character_.

Safety

Must be called from the R main thread.

pub unsafe fn set_opt_str(&self, idx: isize, s: Option<&str>)

Set an element from an optional string.

Safety

Must be called from the R main thread.

pub fn as_sexp(&self) -> SEXP

Get the underlying SEXP.

pub fn into_strvec(self) -> StrVec

Convert to a StrVec wrapper.

pub fn into_sexp(self) -> SEXP

Convert to the underlying SEXP.

pub fn len(&self) -> isize

Get the length.

pub fn is_empty(&self) -> bool

Check if empty.