pub struct StrVecBuilder<'a> {
vec: SEXP,
_scope: &'a ProtectScope,
}Expand description
Builder for constructing string vectors with efficient protection management.
Example
ⓘ
unsafe fn build_strvec(strings: &[&str]) -> SEXP {
let scope = ProtectScope::new();
let builder = StrVecBuilder::new(&scope, strings.len() as isize);
for (i, s) in strings.iter().enumerate() {
builder.set_str(i as isize, s);
}
builder.into_sexp()
}Fields
vec: SEXP_scope: &'a ProtectScopeImplementations
Sourceimpl<'a> StrVecBuilder<'a>
impl<'a> StrVecBuilder<'a>
Sourcepub unsafe fn new(scope: &'a ProtectScope, len: usize) -> Self
pub unsafe fn new(scope: &'a ProtectScope, len: usize) -> Self
Create a new string vector builder with the given length.
Safety
Must be called from the R main thread.
Sourcepub unsafe fn set_opt_str(&self, idx: isize, s: Option<&str>)
pub unsafe fn set_opt_str(&self, idx: isize, s: Option<&str>)
Sourcepub fn into_strvec(self) -> StrVec
pub fn into_strvec(self) -> StrVec
Convert to a StrVec wrapper.