#[doc(hidden)]#[repr(transparent)]pub struct Sendable<T>(pub T);Expand description
Wrapper to mark values as Send for main-thread routing.
Only safe if the value is not accessed on the worker thread and is used exclusively on the main thread.
Tuple Fields
0: TTrait Implementations
Sourceimpl IntoR for Sendable<SEXP>
impl IntoR for Sendable<SEXP>
Sourcetype Error = Infallible
type Error = Infallible
The error type for fallible conversions. Read more
Sourcefn try_into_sexp(self) -> Result<SEXP, Self::Error>
fn try_into_sexp(self) -> Result<SEXP, Self::Error>
Try to convert this value to an R SEXP. Read more
impl<T: Copy> Copy for Sendable<T>
impl<T> Send for Sendable<T>
Layout
Note: Unable to compute type layout, possibly due to this type having generic parameters. Layout can only be computed for concrete, fully-instantiated types.